pub struct FuseTelemetry {
pub uptime_seconds: u64,
pub reads_inflight: u64,
pub reads_inflight_max: u64,
pub read_errors: u64,
pub dir_handles: u64,
pub dir_handles_max: u64,
pub pool_workers: u64,
pub pool_active: u64,
pub pool_queued: u64,
pub passthrough: Option<PassthroughTelemetry>,
}Expand description
Fuse-owned telemetry: uptime, the read/dir-handle gates and their caps, the worker pool, and (Linux only) passthrough state.
Fields
uptime_seconds: u64reads_inflight: u64reads_inflight_max: u64read_errors: u64dir_handles: u64dir_handles_max: u64pool_workers: u64pool_active: u64pool_queued: u64passthrough: Option<PassthroughTelemetry>Trait Implementations
Sourceimpl Clone for FuseTelemetry
impl Clone for FuseTelemetry
Sourcefn clone(&self) -> FuseTelemetry
fn clone(&self) -> FuseTelemetry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FuseTelemetry
Sourceimpl Debug for FuseTelemetry
impl Debug for FuseTelemetry
Sourceimpl Default for FuseTelemetry
impl Default for FuseTelemetry
Sourcefn default() -> FuseTelemetry
fn default() -> FuseTelemetry
Returns the “default value” for a type. Read more
impl Eq for FuseTelemetry
Sourceimpl PartialEq for FuseTelemetry
impl PartialEq for FuseTelemetry
Sourcefn eq(&self, other: &FuseTelemetry) -> bool
fn eq(&self, other: &FuseTelemetry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FuseTelemetry